﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Diagnostics;
using System.Globalization;
using System.Reflection;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.ServiceModel.Activation;
using System.ServiceModel.Web;
using System.Text;
using System.Web;
using Seven.Front.Settings.Business;
using Seven.Front.Settings.Globals;
using Seven.Front.Settings.Objects;
using Seven.Front.Settings.Printing;

namespace Seven.Front.Settings
{
    [ServiceContract(Namespace = "SevenIPMWS")]
    [AspNetCompatibilityRequirements(RequirementsMode = AspNetCompatibilityRequirementsMode.Allowed)]
    public class Maestro
    {
        #region Seguridad

        [WebGet]
        [OperationContract]
        public string GetDatosCombo(string IdJuego, string LangCode)
        {
            try
            {
                return HTMLSelects.Datos(int.Parse(IdJuego));
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region EXTERNAL Log Sheet

        [WebGet]
        [OperationContract]
        public string GetLogSheet(string Inicio, string Final, string Pagina, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    DateTime S = DateTime.Today;
                    try
                    {
                        //S = DateParser.GetDate(Inicio);
                        S = DateTime.Parse(Inicio, ciLocal);
                    }
                    catch (Exception) { }
                    DateTime F = DateTime.Today;
                    try
                    {
                        //F = DateParser.GetDate(Final);
                        F = DateTime.Parse(Final, ciLocal);
                    }
                    catch (Exception) { }
                    return Tablas.LogSheet(S, F, int.Parse(Pagina), iden)
                        .Replace("Página", L.LBL("LblGENPage"))
                        .Replace("LblGENDate", L.LBL("LblGENDate"))
                        .Replace("LblGENObservations", L.LBL("LblGENObservations"))
                        .Replace("LblGENPermit", L.LBL("LblGENPermit"));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\">" + L.LBL("LblGENWrongQuery") + "</br> " + Memoria.Error + "\n" + ex.Message + Inicio + "F" + Final + Pagina + "</p>";
            }
        }

        #endregion

        #region Sistema

        [WebGet]
        [OperationContract]
        public string GetAccordionForm(string U, string N, string D, string I, string LangCode, string SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    string Dir = "src=\"";

                    if (int.Parse(SubDir) == 1)
                    {
                        Dir = "src=\"../";
                    }

                    return ("<div id=\"SevenMenu\">\n" +
                                Logica.GetAccordion(1, iden.U, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                            "</div>\n" +
                            "<table width=\"100%\">\n" +
                                "<tr>\n" +
                                    "<td width=\"50%\">\n" +
                                        "<button type=\"submit\" style=\"width: 100%;\">" +
                                            "<table>" +
                                                "<tr>" +
                                                    "<td><img src=\"img/disk.png\" /></td>" +
                                                    "<td><span style=\"font-size: 8pt;\">LblGENSave</span></td>" +
                                                "</tr>" +
                                            "</table>" +
                                        "</button>" +
                                    "</td>\n" +
                                    "<td width=\"50%\">\n" +
                                        "<button type=\"button\" onclick=\"mostrarAjaxAccordion();\" style=\"width: 100%;\">" +
                                            "<table>" +
                                                "<tr>" +
                                                    "<td><img src=\"img/arrow-return-180-left.png\" /></td>" +
                                                    "<td><span style=\"font-size: 8pt;\">LblGENCancel</span></td>" +
                                                "</tr>" +
                                            "</table>" +
                                        "</button>" +
                                    "</td>\n" +
                                "</tr>\n" +
                            "</table>\n")
                            .Replace("LblGENSave", L.LBL("LblGENSave"))
                            .Replace("LblGENCancel", L.LBL("LblGENCancel"))
                            .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetAccordion(string U, string N, string D, string I, string LangCode, string SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    string Dir = "src=\"";

                    if (int.Parse(SubDir) == 1)
                    {
                        Dir = "src=\"../";
                    }

                    return ("<div id=\"SevenMenu\">\n" +
                                Logica.GetAccordion(0, 0, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                            "</div>\n" +
                            "<button type=\"button\" onclick=\"mostrarAjaxAccordionUser();\" style=\"width: 100%;\">" +
                                "<table>" +
                                    "<tr>" +
                                        "<td><img src=\"img/user.png\" /></td>" +
                                        "<td><span style=\"font-size: 8pt;\">LblGENCustomizeMyMenu</span></td>" +
                                    "</tr>" +
                                "</table>" +
                            "</button>")
                            .Replace("LblGENCustomizeMyMenu", L.LBL("LblGENCustomizeMyMenu"))
                            .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetMenu(string U, string N, string D, string I, string LangCode, int SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    //string Dir = "src=\"";

                    //if (SubDir == 1)
                    //{
                    //    Dir = "src=\"../";
                    //}

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetMenu(0, 0, LangCode, iden));
                    //$("#MenuP ul").append('<li><a href="#tabs-' + i + '"><img src="img/' + datos.rows[i].cell[1] + '" />' + datos.rows[i].cell[2] + '</a></li>');

                    //return ("<div id=\"SevenMenu\">\n" +
                    //            Logica.GetAccordion(0, 0, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                    //        "</div>\n" +
                    //        "<button type=\"button\" onclick=\"mostrarAjaxAccordionUser();\" style=\"width: 100%;\">" +
                    //            "<table>" +
                    //                "<tr>" +
                    //                    "<td><img src=\"img/user.png\" /></td>" +
                    //                    "<td><span style=\"font-size: 8pt;\">LblGENCustomizeMyMenu</span></td>" +
                    //                "</tr>" +
                    //            "</table>" +
                    //        "</button>")
                    //        .Replace("LblGENCustomizeMyMenu", L.LBL("LblGENCustomizeMyMenu"))
                    //        .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetMenuP(string U, string N, string D, string I, string LangCode, int SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    //string Dir = "src=\"";

                    //if (SubDir == 1)
                    //{
                    //    Dir = "src=\"../";
                    //}

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetMenu(1, iden.U, LangCode, iden));
                    //$("#MenuP ul").append('<li><a href="#tabs-' + i + '"><img src="img/' + datos.rows[i].cell[1] + '" />' + datos.rows[i].cell[2] + '</a></li>');

                    //return ("<div id=\"SevenMenu\">\n" +
                    //            Logica.GetAccordion(0, 0, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                    //        "</div>\n" +
                    //        "<button type=\"button\" onclick=\"mostrarAjaxAccordionUser();\" style=\"width: 100%;\">" +
                    //            "<table>" +
                    //                "<tr>" +
                    //                    "<td><img src=\"img/user.png\" /></td>" +
                    //                    "<td><span style=\"font-size: 8pt;\">LblGENCustomizeMyMenu</span></td>" +
                    //                "</tr>" +
                    //            "</table>" +
                    //        "</button>")
                    //        .Replace("LblGENCustomizeMyMenu", L.LBL("LblGENCustomizeMyMenu"))
                    //        .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Configuración del Usuario

        [WebGet]
        [OperationContract]
        public string PutConfiguracionUsuario(string IdOperador, string factura, string alertar_sobreventa, string calcular_sobreventa_cupos
            , string permitir_sobreventa, string permitir_doblepreasignacion, string impresora, string impresora_cheq, string impresora_fact, string impresora_rec
            , string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ConfigUsuario elemento = new ConfigUsuario();
                    elemento.IdOperador = iden.U;
                    try
                    {
                        elemento.factura = int.Parse(factura) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.factura = false;
                    }
                    try
                    {
                        elemento.alertar_sobreventa = int.Parse(alertar_sobreventa) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.alertar_sobreventa = false;
                    }
                    try
                    {
                        elemento.calcular_sobreventa_cupos = int.Parse(calcular_sobreventa_cupos) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.calcular_sobreventa_cupos = false;
                    }
                    try
                    {
                        elemento.permitir_sobreventa = int.Parse(permitir_sobreventa) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.permitir_sobreventa = false;
                    }
                    //try
                    //{
                    //    elemento.permitir_doblepreasignacion = int.Parse(permitir_doblepreasignacion) == 1 ? true : false;
                    //}
                    //catch
                    //{
                    //    elemento.permitir_doblepreasignacion = false;
                    //}
                    elemento.permitir_doblepreasignacion = false;
                    elemento.impresora = impresora;
                    elemento.impresora_cheq = impresora_cheq;
                    elemento.impresora_fact = impresora_fact;
                    elemento.impresora_rec = impresora_rec;

                    int res = -1;

                    res = Logica.PutConfiguracionUsuario(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Monedas

        [WebGet]
        [OperationContract]
        public string GetMonedas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetMonedas(0, new Moneda(0, "", "", 0, 0, 0, DateTime.Now, false, false, Eliminados, false), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutMonedas(string IdMone, string Codigo, string Descripcion, string Tasa, string Comision, short Decimales, string Convertible, string Facturable,
            string Referencia, string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode,
            string Empresa, string DepAdel, string PagoTarj)
        {
            try
            {
                int IdMone2 = 0;
                try { IdMone2 = int.Parse(IdMone); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Moneda elemento = new Moneda();
                    elemento.id_mone = IdMone2;
                    elemento.cod_mone = Codigo;
                    elemento.desc_mone = Descripcion;
                    elemento.tasa = float.Parse(Tasa);
                    elemento.comision = float.Parse(Comision);
                    elemento.decimales = Decimales;

                    bool Conv = false;
                    try
                    {
                        if (Convertible.Equals("True"))
                        {
                            Conv = true;
                        }
                    }
                    catch { }
                    elemento.convertible = Conv;

                    bool Fact = false;
                    try
                    {
                        if (Facturable.Equals("True"))
                        {
                            Fact = true;
                        }
                    }
                    catch { }
                    elemento.facturable = Fact;

                    bool Refe = false;
                    try
                    {
                        if (Referencia.Equals("True"))
                        {
                            Refe = true;
                        }
                    }
                    catch { }
                    elemento.refer_mone = Refe;

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutMonedas(elemento, Empresa, int.Parse(DepAdel), int.Parse(PagoTarj), iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetMonedasXServFacturacionCombo(string id_con0, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridCombo(Logica.GetMonedasXServFacturacionCombo(int.Parse(id_con0), iden)).Replace("value:", "");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Nacionalidades

        [WebGet]
        [OperationContract]
        public string GetNacionalidades(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetNacionalidades(0, new Nacionalidad(0, "", "", Eliminados), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutNacionalidades(string IdNaci, string Nac, string DescNac, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdNaci2 = 0;
                try { IdNaci2 = int.Parse(IdNaci); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Nacionalidad elemento = new Nacionalidad();
                    elemento.id_naci = IdNaci2;
                    elemento.nacionalidad = Nac;
                    elemento.desc_nac = DescNac;

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutNacionalidades(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Impuestos

        [WebGet]
        [OperationContract]
        public string GetImpuestos(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetImpuestos(0, new Impuesto(0, "", 0, Eliminados, false, 0, false), "", iden));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetImpuestosMoneda(string IdImpu, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetImpuestosMoneda(int.Parse(IdImpu), iden));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutImpuestos(string IdImpu, string Desc, string Porc, string Canje, string Nivel, string ApliSup, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdImpu2 = 0;
                try { IdImpu2 = int.Parse(IdImpu); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Impuesto elemento = new Impuesto();
                    elemento.id_impu = IdImpu2;
                    elemento.desc_impu = Desc;
                    elemento.porc_impu = float.Parse(Porc);

                    bool EsCanje = false;
                    try
                    {
                        if (Canje.Equals("True"))
                        {
                            EsCanje = true;
                        }
                    }
                    catch { }
                    elemento.afecta_cange = EsCanje;

                    elemento.nivel = short.Parse(Nivel);

                    bool EsApliSup = false;
                    try
                    {
                        if (ApliSup.Equals("True"))
                        {
                            EsApliSup = true;
                        }
                    }
                    catch { }
                    elemento.apli_sup = EsApliSup;

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutImpuestos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutImpuestosMoneda(string IdImpu, string IdMone, string IdCuenta, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ImpuestoMoneda elemento = new ImpuestoMoneda();
                    elemento.id_impu = int.Parse(IdImpu);
                    elemento.id_mone = int.Parse(IdMone);
                    elemento.id_cuenta = int.Parse(IdCuenta);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutImpuestosMoneda(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Conceptos de Produccion

        [WebGet]
        [OperationContract]
        public string GetConceptosProduccion(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetConcProd(0, new ConProd(0, "", Eliminados, false, 0), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetConceptosProduccionMoneda(string IdCon1, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetConcProdMoneda(int.Parse(IdCon1), iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutConceptosProduccion(string IdCon1, string Desc, string Prod, string IdCagr, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdCon12 = 0;
                try { IdCon12 = int.Parse(IdCon1); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ConProd elemento = new ConProd();
                    elemento.id_con1 = IdCon12;
                    elemento.desc_con1 = Desc;

                    bool Produccion = false;
                    try
                    {
                        if (Prod.Equals("True"))
                        {
                            Produccion = true;
                        }
                    }
                    catch { }
                    elemento.produccion = Produccion;

                    elemento.id_cagr = int.Parse(IdCagr);

                    try
                    {
                        elemento.eliminado = false;
                        if (int.Parse(Eliminado) == 1)
                        {
                            elemento.eliminado = true;
                        }
                    }
                    catch { }

                    int res = 0;

                    res = Logica.PutConcProd(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutConceptosProduccionMoneda(string IdCon1, string IdMone, string IdCuenta, string IdCuentaCC, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ConProdMoneda elemento = new ConProdMoneda();
                    elemento.id_con1 = int.Parse(IdCon1);
                    elemento.id_mone = int.Parse(IdMone);
                    elemento.id_cuenta = int.Parse(IdCuenta);
                    elemento.id_cuentacc = int.Parse(IdCuentaCC);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutConcProdMoneda(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Grupos de Producción

        [WebGet]
        [OperationContract]
        public string GetGruposProduccion(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetGruposProduccion(0, new GrupoProd(0, "", Eliminados), "", iden));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutGruposProduccion(string IdCagr, string DescCagr, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdCagr2 = 0;
                try { IdCagr2 = int.Parse(IdCagr); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    GrupoProd elemento = new GrupoProd();
                    elemento.id_cagr = IdCagr2;
                    elemento.descrip_cagr = DescCagr;

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutGruposProduccion(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Empresas

        [WebGet]
        [OperationContract]
        public string GetEmpresas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetEmpresas(0, new Empresa(0, "", false, false, Eliminados), "", iden));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutEmpresas(string IdAgen, string Agencia, string Directo, string Cupos, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdAgen2 = 0;
                try { IdAgen2 = int.Parse(IdAgen); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Empresa elemento = new Empresa();
                    elemento.id_agen = IdAgen2;
                    elemento.agencia = Agencia;

                    bool Dir = false;
                    if (Directo.Equals("True"))
                    {
                        Dir = true;
                    }
                    elemento.directo = Dir;

                    bool Comparte = false;
                    if (Cupos.Equals("True"))
                    {
                        Comparte = true;
                    }
                    elemento.comparte_cupos = Comparte;

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutEmpresas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Mercados

        [WebGet]
        [OperationContract]
        public string GetMercados(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetMercados(0, new Mercado(0, "", Eliminados), "", iden));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutMercados(string IdMerc, string Desc, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdMercado = 0;
                try { IdMercado = int.Parse(IdMerc); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    Mercado elemento = new Mercado();
                    elemento.id_merc = IdMercado;
                    elemento.desc_merc = Desc;

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutMercados(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Descuentos

        [WebGet]
        [OperationContract]
        public string GetDescuentos(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetDescuentos(0, new Descuento(0, "", false, "", 0, 0, Eliminados), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetDescuentosMoneda(string IdDcto, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetDescuentosMoneda(int.Parse(IdDcto), iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutDescuentos(string IdDcto, string Desc, string Porc, short Tipo, string Pass, string Activo, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdDcto2 = 0;
                try { IdDcto2 = int.Parse(IdDcto); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Descuento elemento = new Descuento();
                    elemento.id_dcto = IdDcto2;
                    elemento.desc_dcto = Desc;
                    elemento.porc_dcto = float.Parse(Porc);

                    bool EsActivo = false;
                    try
                    {
                        if (Activo.Equals("True"))
                        {
                            EsActivo = true;
                        }
                    }
                    catch { }
                    elemento.activo = EsActivo;
                    elemento.tipo_dcto = Tipo;
                    elemento.password = Pass;

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutDescuentos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutDescuentosMoneda(string IdDcto, string IdMone, string IdCuenta, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    DescuentoMoneda elemento = new DescuentoMoneda();
                    elemento.id_dcto = int.Parse(IdDcto);
                    elemento.id_mone = int.Parse(IdMone);
                    elemento.id_cuenta = int.Parse(IdCuenta);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutDescuentosMoneda(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Servicios de Facturación

        [WebGet]
        [OperationContract]
        public string GetServFact(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServFact(0, new ServFact(0, 0, "", "", false, Eliminados), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetServFactMoneda(string IdCon0, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServFactMoneda(int.Parse(IdCon0), iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetServFactMonedasImpuesto(string IdPre0, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServFactMonedasImpuesto(int.Parse(IdPre0), iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetServFactDescuento(string IdCon0, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServFactDescuento(int.Parse(IdCon0), iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServFact(string IdCon0, string Code, string Desc, string Cargo, string IdCon1, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdCon02 = 0;
                try { IdCon02 = int.Parse(IdCon0); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    ServFact elemento = new ServFact();
                    elemento.id_con0 = IdCon02;
                    elemento.cod_con0 = Code;
                    elemento.desc_con0 = Desc;

                    bool EsCargo = false;
                    try
                    {
                        if (Cargo.Equals("True"))
                        {
                            EsCargo = true;
                        }
                    }
                    catch { }
                    elemento.cargo = EsCargo;

                    elemento.id_con1 = int.Parse(IdCon1);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutServFact(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServFactMoneda(string IdCon0, string IdMone, string Precio, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    ServFactMoneda elemento = new ServFactMoneda();
                    elemento.id_con0 = int.Parse(IdCon0);
                    elemento.id_mone = int.Parse(IdMone);
                    elemento.precio = float.Parse(Precio, ciLocal);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutServFactMoneda(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServFactMonedasImpuesto(string IdPre0, string IdImpu, string Incluido, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ServFactMoneImpuesto elemento = new ServFactMoneImpuesto();
                    elemento.id_pre0 = int.Parse(IdPre0);
                    elemento.id_impu = int.Parse(IdImpu);

                    bool EsIncluido = false;
                    try
                    {
                        if (Incluido.Equals("True"))
                        {
                            EsIncluido = true;
                        }
                    }
                    catch { }
                    elemento.incluido = EsIncluido;

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutServFactMonedasImpuesto(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServFactDescuento(string IdCon0, string IdDcto, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ServFactDescuento elemento = new ServFactDescuento();
                    elemento.id_con0 = int.Parse(IdCon0);
                    elemento.id_dcto = int.Parse(IdDcto);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutServFactDescuento(elemento, LangCode, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Habitaciones

        [WebGet]
        [OperationContract]
        public string GetHabitaciones(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetHabitaciones(0, new Habitacion(0, 0, "", false, "", Eliminados, 0), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutHabitaciones(string IdHabi, string Habitacion, string IdThab, string Grupo, string IdCtgt, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdHabi2 = 0;
                try { IdHabi2 = int.Parse(IdHabi); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Habitacion elemento = new Habitacion();
                    elemento.id_habi = IdHabi2;
                    elemento.habitacion = Habitacion;
                    elemento.id_thab = int.Parse(IdThab);
                    elemento.grupo = Grupo;
                    elemento.id_ctgt = int.Parse(IdCtgt);
                    elemento.limpia = true;

                    elemento.eliminado = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            elemento.eliminado = true;
                        }
                    }
                    catch { }

                    Habitacion original = elemento;

                    if (IdHabi2 != 0)
                    {
                        original = Logica.GetHabitacion(IdHabi2, iden);
                    }

                    int res = 0;

                    res = Logica.PutHabitaciones(elemento, original, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetHabitacionesCaracteristicas(string IdHabi, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetHabitacionesCaracteristicas(int.Parse(IdHabi), iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutHabitacionesCaracteristicas(string IdHabi, string IdCaha, string IdCuenta, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    HabitacionCaract elemento = new HabitacionCaract();
                    elemento.id_habi = int.Parse(IdHabi);
                    elemento.id_caha = int.Parse(IdCaha);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutHabitacionesCaracteristicas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Tipos de Habitaciones

        [WebGet]
        [OperationContract]
        public string GetTipoHabitaciones(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetTipoHabitaciones(0, new TipoHabitacion(0, 0, "", "", 0, 0, Eliminados, 0), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutTipoHabitaciones(string IdThab, string IdCon0, string TipoHab, string Desc, string Adultos, string Ninos, string Orden, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdThab2 = 0;
                try { IdThab2 = int.Parse(IdThab); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    if (!ValidarExpre(TipoHab))
                    {
                        throw new Exception("ERR_THAB_UHAB_PUT_001");
                    }

                    TipoHabitacion elemento = new TipoHabitacion();
                    elemento.id_thab = IdThab2;
                    elemento.id_con0 = int.Parse(IdCon0);
                    elemento.tipo_hab = TipoHab;
                    elemento.desc_t_hab = Desc;
                    elemento.max_adultos = short.Parse(Adultos);
                    elemento.max_ninos = short.Parse(Ninos);
                    elemento.orden_visual = short.Parse(Orden);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutTipoHabitaciones(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        public bool ValidarExpre(string Codigo)
        {
            bool Valido = true;
            foreach (char c in Codigo)
            {
                int nasci = c;
                if (!((nasci >= 65 && nasci <= 90) || (nasci >= 97 && nasci <= 122) || (nasci == 95) || (nasci >= 48 && nasci <= 57)))
                {
                    Valido = false;
                }
            }
            return Valido;
        }

        #endregion

        #region Usos de Habitaciones

        [WebGet]
        [OperationContract]
        public string GetUsoHabitaciones(string IdThab, string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetUsoHabitaciones(0, new UsoHabitacion(0, short.Parse(IdThab), "", "", 0, 0, Eliminados), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutUsoHabitaciones(string IdUhab, string IdThab, string UsoHab, string Desc, string Adultos, string Ninos, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                short IdUhab2 = 0;
                try { IdUhab2 = short.Parse(IdUhab); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    if (!ValidarExpre(UsoHab))
                    {
                        throw new Exception("ERR_THAB_UHAB_PUT_001");
                    }

                    UsoHabitacion elemento = new UsoHabitacion();
                    elemento.id_uhab = IdUhab2;
                    elemento.id_thab = int.Parse(IdThab);
                    elemento.uso_hab = UsoHab;
                    elemento.desc_uso_hab = Desc;
                    elemento.max_adultos = short.Parse(Adultos);
                    elemento.max_ninos = short.Parse(Ninos);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutUsoHabitaciones(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Características

        [WebGet]
        [OperationContract]
        public string GetCaracteristicas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetCaracteristicas(0, new Caracteristica(0, "", Eliminados), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutCaracteristicas(string IdCaha, string Desc, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdCaha2 = 0;
                try { IdCaha2 = int.Parse(IdCaha); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Caracteristica elemento = new Caracteristica();
                    elemento.id_caha = IdCaha2;
                    elemento.desc_c_hab = Desc;

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutCaracteristicas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Grupos de Disponibilidades

        [WebGet]
        [OperationContract]
        public string GetGruposDisponibilidades(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetGruposDisponibilidades(0, new GrupoDisponibilidad(0, "", 0, Eliminados), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetGruposDisponibilidadesTipoHabi(string IdDisp, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetGruposDisponibilidadesTipoHabi(int.Parse(IdDisp), iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutGruposDisponibilidades(string IdDisp, string Desc, string Orden, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int IdDisp2 = 0;
                try { IdDisp2 = int.Parse(IdDisp); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    GrupoDisponibilidad elemento = new GrupoDisponibilidad();
                    elemento.id_disp = IdDisp2;
                    elemento.desc_disp = Desc;
                    elemento.orden_visual = short.Parse(Orden);

                    elemento.activo = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            elemento.activo = true;
                        }
                    }
                    catch { }

                    int res = 0;

                    res = Logica.PutGruposDisponibilidades(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutGruposDisponibilidadesTipoHabi(string IdDisp, string Elementos
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    string Elementos2 = "";
                    if (!string.IsNullOrEmpty(Elementos))
                    {
                        try
                        {
                            string[] Elems = Elementos.Split(',');
                            bool Primero = true;
                            foreach (string Elem in Elems)
                            {
                                if (!Primero)
                                {
                                    Elementos2 += "|";
                                }
                                else
                                {
                                    Primero = false;
                                }
                                Elementos2 += int.Parse(Elem).ToString();
                            }
                        }
                        catch { }
                    }

                    int res = 0;

                    res = Logica.PutGruposDisponibilidadesTipoHabi(int.Parse(IdDisp), Elementos2, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Agentes de Ventas

        [WebGet]
        [OperationContract]
        public string GetAgenteVentas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetAgenteVentas(0, new Objects.AgenteVentas(0, "", "", "", "", Eliminados), "", iden));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutAgenteVentas(string id_venta, string Nombre, string telefono, string celular, string email, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int id_venta2 = 0;
                try { id_venta2 = int.Parse(id_venta); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Objects.AgenteVentas elemento = new Objects.AgenteVentas();
                    elemento.id_venta = id_venta2;
                    elemento.Nombre = Nombre;
                    elemento.telefono = telefono;
                    elemento.celular = celular;
                    elemento.email = email;


                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutAgenteVentas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Servicios Simples de Agencias

        [WebGet]
        [OperationContract]
        public string GetServSimplesAgencias(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServSimplesAgencias(0, new ServSimpleAgencias(0, "", "", "", 0, false, Eliminados, false, 0), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServSimplesAgencias(string id_csim, string cod_csim, string desc_csim, string tipo_csim, string id_con1
            , string csim_dp, string Eliminado, string Porcentual, string Valor, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int id_csim2 = 0;
                try { id_csim2 = int.Parse(id_csim); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ServSimpleAgencias elemento = new ServSimpleAgencias();
                    elemento.id_csim = id_csim2;
                    elemento.cod_csim = cod_csim;
                    elemento.desc_csim = desc_csim;
                    elemento.tipo_csim = tipo_csim;
                    elemento.id_con1 = int.Parse(id_con1);
                    elemento.csim_dp = false;
                    try
                    {
                        elemento.csim_dp = bool.Parse(csim_dp);
                    }
                    catch { }
                    elemento.Porcentual = false;
                    try
                    {
                        elemento.Porcentual = bool.Parse(Porcentual);
                    }
                    catch { }
                    try
                    {
                        elemento.Valor = float.Parse(Valor);
                    }
                    catch
                    {
                        if (!elemento.csim_dp)
                        {
                            throw new Exception(L.ERR("ERR_GEN_PUT_010"));
                        }
                        else
                        {
                            elemento.Valor = 0;
                        }
                    }

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutServSimplesAgencias(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Servicios de Agencias

        [WebGet]
        [OperationContract]
        public string GetServiciosAgencias(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(
                        Logica.GetServiciosAgencias(0, new ServicioAgencias(0, "", "", "", 0, 0, true, 0, DateTime.Today, 0, Eliminados), "", iden));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServiciosAgencias(string id_cfag, string cod_cfag, string desc_cfag, string tipo_cfag, string id_uhab, string id_ralo,
            string cantidad, string id_con1, string fecha_fija, string id_csim, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int id_cfag2 = 0;
                try { id_cfag2 = int.Parse(id_cfag); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ServicioAgencias elemento = new ServicioAgencias();
                    elemento.id_cfag = id_cfag2;
                    elemento.cod_cfag = cod_cfag;
                    elemento.desc_cfag = desc_cfag;
                    elemento.tipo_cfag = tipo_cfag;
                    elemento.id_uhab = short.Parse(id_uhab);
                    elemento.id_ralo = short.Parse(id_ralo);
                    try
                    {
                        elemento.cantidad = int.Parse(cantidad) == 1 ? true : false;
                    }
                    catch { }
                    try
                    {
                        elemento.id_con1 = int.Parse(id_con1);
                    }
                    catch
                    {
                        elemento.id_con1 = 0;
                    }
                    try
                    {
                        elemento.fecha_fija = DateTime.Parse(fecha_fija);
                    }
                    catch
                    {
                        elemento.fecha_fija = DateTime.Today;
                    }
                    try
                    {
                        elemento.id_csim = int.Parse(id_csim);
                    }
                    catch
                    {
                        elemento.id_csim = 0;
                    }

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutServiciosAgencias(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Servicios de Agencias - Impuestos

        [WebGet]
        [OperationContract]
        public string GetServiciosAgenciasImpuestos(string id_cfag, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServiciosAgenciasImpuestos(int.Parse(id_cfag), iden));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServiciosAgenciasImpuestos(string id_imag, string id_cfag, string id_impu, string Activo, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int id_imag2 = 0;
                try { id_imag2 = int.Parse(id_imag); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    ServiciosAgenciasImpuesto elemento = new ServiciosAgenciasImpuesto();
                    elemento.id_imag = id_imag2;
                    elemento.id_cfag = int.Parse(id_cfag);
                    elemento.id_impu = int.Parse(id_impu);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.Activo = Elim;

                    int res = -1;

                    res = Logica.PutServiciosAgenciasImpuestos(elemento, iden);

                    if (res > 0 || res < 0)
                    {
                        return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                    }
                    else
                    {
                        return L.ERR("LblGENUnauthorizedUser");
                    }
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Servicios de Agencias - Servicios Simples

        [WebGet]
        [OperationContract]
        public string GetServiciosAgenciaServiciosSimples(string id_cfag, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServiciosAgenciaServiciosSimples(int.Parse(id_cfag), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServiciosAgenciaServiciosSimples(string id_csim, string id_cfag, string orden, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    ServicioAgenciaServicioSimple elemento = new ServicioAgenciaServicioSimple();
                    try
                    {
                        elemento.id_csim = int.Parse(id_csim);
                    }
                    catch
                    {
                        elemento.id_csim = 0;
                    }
                    elemento.id_csim = int.Parse(id_csim);
                    elemento.id_cfag = int.Parse(id_cfag);
                    elemento.orden = short.Parse(orden);

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutServiciosAgenciaServiciosSimples(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Servicios de Agencias - Generar

        [WebGet]
        [OperationContract]
        public string PutServiciosAgenciasGenerar(string id_con1, string Impuestos, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {

                    int res = 0;

                    res = Logica.PutServiciosAgenciasGenerar(int.Parse(id_con1), Impuestos, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Enlaces para Prepagos

        [WebGet]
        [OperationContract]
        public string GetEnlacesPrepagos(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetEnlacesPrepagos(0, new EnlacePrepagos(0, "", 0, "", 0, 0, 0, 0, 0, Eliminados), "", iden));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutEnlacesPrepagos(string id_endg, string cod_endg, string id_mone, string tipo, string id_cuenta, string id_cuenta_ofic, string id_cuenta_cc
            , string id_cuenta_dev, string id_termid, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int id_endg2 = 0;
                try { id_endg2 = int.Parse(id_endg); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    EnlacePrepagos elemento = new EnlacePrepagos();
                    elemento.id_endg = id_endg2;
                    elemento.cod_endg = cod_endg;
                    elemento.id_mone = int.Parse(id_mone);
                    elemento.tipo = tipo;
                    elemento.id_cuenta = int.Parse(id_cuenta);
                    elemento.id_cuenta_ofic = int.Parse(id_cuenta_ofic);
                    elemento.id_cuenta_cc = int.Parse(id_cuenta_cc);
                    elemento.id_cuenta_dev = int.Parse(id_cuenta_dev);
                    elemento.id_termid = int.Parse(id_termid);


                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutEnlacesPrepagos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Definición de Composiciones

        [WebGet]
        [OperationContract]
        public string GetExpresionesRalo(string id_expre, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetExpresionesRalo(int.Parse(id_expre), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetExpresionesMone(string id_expre, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetExpresionesMone(int.Parse(id_expre), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetExpresionesUhab(string id_expre, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetExpresionesUhab(int.Parse(id_expre), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetExpresionesCont(string id_expre, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetExpresionesCont(int.Parse(id_expre), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetExpresionesNaci(string id_expre, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetExpresionesNaci(int.Parse(id_expre), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetCalculoComp(string Codigo, string FecIni, string FecFin, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return String.Format("{0:N2}", Logica.GetCalculoComp(Codigo, DateTime.Parse(FecIni), DateTime.Parse(FecFin), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutComposiciones(string id_compo, string codigo, string descripcion, string id_expre, string id_cuenta, string id_cuenta_ce
            , string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    Composicion elemento = new Composicion();
                    try
                    {
                        elemento.id_compo = int.Parse(id_compo);
                    }
                    catch
                    {
                        elemento.id_compo = 0;
                    }
                    elemento.codigo = codigo;
                    elemento.descripcion = descripcion;
                    elemento.id_expre = int.Parse(id_expre);
                    elemento.id_cuenta = int.Parse(id_cuenta);
                    elemento.id_cuenta_ce = int.Parse(id_cuenta_ce);

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutComposiciones(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutExpresionesCompuestas(string id_expre, string nombre_expr, string operador, string id_referx, string id_referx2, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    ExpresionCompuesta elemento = new ExpresionCompuesta();
                    try
                    {
                        elemento.id_expre = int.Parse(id_expre);
                    }
                    catch
                    {
                        elemento.id_expre = 0;
                    }
                    elemento.nombre_expr = nombre_expr;
                    elemento.operador = int.Parse(operador);
                    elemento.id_referx = int.Parse(id_referx);
                    elemento.id_referx2 = int.Parse(id_referx2);

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutExpresionesCompuestas(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutExpresiones(string id_expre, string nombre_expr, string ktegoria, string id_noex
            , string usaralo, string ralonot, string sralo, string usamone, string monenot, string smone, string usauhab, string uhabnot, string suhab
            , string usacont, string contnot, string scont, string usanaci, string nacinot, string snaci, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Expresion elemento = new Expresion();
                    try
                    {
                        elemento.id_expre = int.Parse(id_expre);
                    }
                    catch
                    {
                        elemento.id_expre = 0;
                    }
                    elemento.nombre_expr = nombre_expr;
                    elemento.ktegoria = short.Parse(ktegoria);
                    elemento.id_noex = int.Parse(id_noex);
                    try { elemento.usaralo = int.Parse(usaralo) == 1 ? true : false; }
                    catch { elemento.usaralo = false; }
                    try { elemento.ralonot = int.Parse(ralonot) == 1 ? true : false; }
                    catch { elemento.ralonot = false; }
                    elemento.sralo = sralo;
                    try { elemento.usamone = int.Parse(usamone) == 1 ? true : false; }
                    catch { elemento.usamone = false; }
                    try { elemento.monenot = int.Parse(monenot) == 1 ? true : false; }
                    catch { elemento.monenot = false; }
                    elemento.smone = smone;
                    try { elemento.usauhab = int.Parse(usauhab) == 1 ? true : false; }
                    catch { elemento.usauhab = false; }
                    try { elemento.uhabnot = int.Parse(uhabnot) == 1 ? true : false; }
                    catch { elemento.uhabnot = false; }
                    elemento.suhab = suhab;
                    try { elemento.usacont = int.Parse(usacont) == 1 ? true : false; }
                    catch { elemento.usacont = false; }
                    try { elemento.contnot = int.Parse(contnot) == 1 ? true : false; }
                    catch { elemento.contnot = false; }
                    elemento.scont = scont;
                    try { elemento.usanaci = int.Parse(usanaci) == 1 ? true : false; }
                    catch { elemento.usanaci = false; }
                    try { elemento.nacinot = int.Parse(nacinot) == 1 ? true : false; }
                    catch { elemento.nacinot = false; }
                    elemento.snaci = snaci;

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutExpresiones(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Valores Estadísticos Externos

        [WebGet]
        [OperationContract]
        public string GetValoresEstadisticosExternos(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        int eli = int.Parse(Eliminado);
                        if (eli == 1)
                        {
                            Eliminados = true;
                        }
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetValoresEstadisticosExternos(0, new ValorEstadisticoExterno(0, "", false, 0, Eliminados), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutValoresEstadisticosExternos(string id_noex, string desc_noex, string tipo_fijo, string valor_fijo, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                int id_noex2 = 0;
                try { id_noex2 = int.Parse(id_noex); }
                catch { }

                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ValorEstadisticoExterno elemento = new ValorEstadisticoExterno();
                    elemento.id_noex = id_noex2;
                    elemento.desc_noex = desc_noex;
                    bool EsTipoFijo = false;
                    if (tipo_fijo.Equals("True"))
                    {
                        EsTipoFijo = true;
                    }
                    elemento.tipo_fijo = EsTipoFijo;
                    elemento.valor_fijo = float.Parse(valor_fijo);

                    bool Elim = false;
                    try
                    {
                        if (int.Parse(Eliminado) == 1)
                        {
                            Elim = true;
                        }
                    }
                    catch { }

                    elemento.eliminado = Elim;

                    int res = 0;

                    res = Logica.PutValoresEstadisticosExternos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Camareras

        [WebGet]
        [OperationContract]
        public string GetCamareras(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetCamareras(0, new Camarera(0, "", Eliminados), "", iden));
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutCamareras(string id_cama, string nombre_cama, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Camarera elemento = new Camarera();
                    try
                    {
                        elemento.id_cama = short.Parse(id_cama);
                    }
                    catch
                    {
                        elemento.id_cama = 0;
                    }
                    elemento.nombre_cama = nombre_cama;
                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = 0;

                    res = Logica.PutCamareras(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Tipos de Temporadas

        [WebGet]
        [OperationContract]
        public string GetTipoTemporadas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetTipoTemporadas(0, new TipoTemporada(0, "", Eliminados), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutTipoTemporadas(string id_ttem, string descripcion, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    TipoTemporada elemento = new TipoTemporada();
                    try
                    {
                        elemento.id_ttem = int.Parse(id_ttem);
                    }
                    catch
                    {
                        elemento.id_ttem = 0;
                    }
                    elemento.descripcion = descripcion;

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutTipoTemporadas(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Rango de Habitaciones

        [WebGet]
        [OperationContract]
        public string GetRangoHabi(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetRangoHabi(new RangoHabi(), Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetRangoHabiDet(string Modo, string id_rango, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetRangoHabiDet(int.Parse(Modo), int.Parse(id_rango), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutRangoHabi(string id_rango, string codigo_rango, string desc_rango, string eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    RangoHabi elemento = new RangoHabi();
                    try
                    {
                        elemento.id_rango = int.Parse(id_rango);
                    }
                    catch
                    {
                        elemento.id_rango = 0;
                    }
                    elemento.codigo_rango = codigo_rango;
                    elemento.desc_rango = desc_rango;
                    elemento.eliminado = false;

                    int res = -1;

                    res = Logica.PutRangoHabi(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutRangoHabiDet(string Modo, string id_rango, string ElementosA, string ElementosB, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int vModo = int.Parse(Modo);
                    string Elementos = "";
                    if (vModo == 0 || vModo == 1)
                    {
                        Elementos = ElementosA;
                    }
                    else
                    {
                        Elementos = ElementosB;
                    }

                    int res = -1;

                    res = Logica.PutRangoHabiDet(vModo, int.Parse(id_rango), Elementos, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelRangoHabi(string id_rango, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelRangoHabi(int.Parse(id_rango), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Regímenes de Alojamiento

        [WebGet]
        [OperationContract]
        public string GetRegimenesAlojamiento(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    RegimenAlojamiento elemento = new RegimenAlojamiento();
                    elemento.id_ralo = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetRegimenesAlojamiento(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutRegimenesAlojamiento(string id_ralo, string cod_ralo, string desc_ralo, string eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    RegimenAlojamiento elemento = new RegimenAlojamiento();
                    try
                    {
                        elemento.id_ralo = int.Parse(id_ralo);
                    }
                    catch
                    {
                        elemento.id_ralo = 0;
                    }
                    elemento.cod_ralo = cod_ralo;
                    elemento.desc_ralo = desc_ralo;
                    elemento.eliminado = false;

                    int res = -1;

                    res = Logica.PutRegimenesAlojamiento(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelRegimenesAlojamiento(string id_ralo, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelRegimenesAlojamiento(int.Parse(id_ralo), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Regímenes de Alojamiento - Conceptos

        [WebGet]
        [OperationContract]
        public string GetRegAlojConceptos(string id_ralo, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetRegAlojConceptos(int.Parse(id_ralo), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutRegAlojConceptos(string id_rali, string id_ralo, string id_con0, string tipo, string PPax, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    RegAlojConcepto elemento = new RegAlojConcepto();
                    try
                    {
                        elemento.id_rali = int.Parse(id_rali);
                    }
                    catch
                    {
                        elemento.id_rali = 0;
                    }
                    elemento.id_ralo = int.Parse(id_ralo);
                    elemento.id_con0 = int.Parse(id_con0);
                    elemento.tipo = int.Parse(tipo);
                    elemento.PPax = false;
                    try
                    {
                        elemento.PPax = bool.Parse(PPax);
                    }
                    catch { }

                    int res = -1;

                    res = Logica.PutRegAlojConceptos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelRegAlojConceptos(string id_rali, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelRegAlojConceptos(int.Parse(id_rali), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Regímenes de Alojamiento - Precios

        [WebGet]
        [OperationContract]
        public string GetRegAlojPrecios(string id_rali, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetRegAlojPrecios(int.Parse(id_rali), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutRegAlojPrecios(string id_rald, string id_rali, string id_pre0, string precio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    RegAlojPrecio elemento = new RegAlojPrecio();
                    try
                    {
                        elemento.id_rald = int.Parse(id_rald);
                    }
                    catch
                    {
                        elemento.id_rald = 0;
                    }
                    elemento.id_rali = int.Parse(id_rali);
                    elemento.id_pre0 = int.Parse(id_pre0);
                    elemento.precio = float.Parse(precio);


                    int res = -1;

                    res = Logica.PutRegAlojPrecios(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelRegAlojPrecios(string id_rald, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelRegAlojPrecios(int.Parse(id_rald), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Configuración de Empresas

        [WebGet]
        [OperationContract]
        public string GetConfigEmpresas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    ConfigEmpresa elemento = new ConfigEmpresa();
                    elemento.IdEmpresa = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetConfigEmpresas(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutConfigEmpresas(string IdEmpresa, string Empresa, string CodEmpresa, string Nombre_Hotel, string Razon_Soc, string Ced_Jud, string Telefono
            , string Email, string Direccion, string Logo, string NFactura, string PrefijoFactura, string NRecibo, string NNotas, string PrefijoRecibo
            , string SitioWeb, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ConfigEmpresa elemento = new ConfigEmpresa();
                    try
                    {
                        elemento.IdEmpresa = short.Parse(IdEmpresa);
                    }
                    catch
                    {
                        elemento.IdEmpresa = 0;
                    }
                    elemento.Empresa = Empresa;
                    elemento.CodEmpresa = Empresa;
                    elemento.Nombre_Hotel = Nombre_Hotel;
                    elemento.Razon_Soc = Razon_Soc;
                    elemento.Ced_Jud = Ced_Jud;
                    elemento.Telefono = Telefono;
                    elemento.Email = Email;
                    elemento.Direccion = Direccion;
                    elemento.Logo = "";
                    elemento.NFactura = 0;
                    elemento.PrefijoFactura = PrefijoFactura;
                    elemento.NRecibo = 0;
                    elemento.NNotas = 0;
                    elemento.PrefijoRecibo = PrefijoRecibo;
                    elemento.SitioWeb = SitioWeb;

                    int res = -1;

                    res = Logica.PutConfigEmpresas(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelConfigEmpresas(string IdEmpresa, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelConfigEmpresas(short.Parse(IdEmpresa), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tipos de Cobro

        [WebGet]
        [OperationContract]
        public string GetTipoCobros(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    TipoCobro elemento = new TipoCobro();
                    elemento.id_tcob = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetTipoCobros(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutTipoCobros(string id_tcob, string cod_tcob, string desc_tcob, string id_mone, string id_fpag, string detallado, string val_tarj, string comision, string id_cuenta, string id_cuenta_tip, string id_termid, string TipoCxc, string eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    TipoCobro elemento = new TipoCobro();
                    try
                    {
                        elemento.id_tcob = int.Parse(id_tcob);
                    }
                    catch
                    {
                        elemento.id_tcob = 0;
                    }
                    elemento.cod_tcob = cod_tcob;
                    elemento.desc_tcob = desc_tcob;
                    elemento.id_mone = int.Parse(id_mone);
                    elemento.id_fpag = int.Parse(id_fpag);
                    elemento.detallado = false;
                    try
                    {
                        elemento.detallado = bool.Parse(detallado);
                    }
                    catch { }
                    elemento.val_tarj = val_tarj;
                    elemento.comision = float.Parse(comision);
                    elemento.id_cuenta = int.Parse(id_cuenta);
                    elemento.id_cuenta_tip = int.Parse(id_cuenta_tip);
                    elemento.id_termid = int.Parse(id_termid);
                    elemento.TipoCxc = false;
                    try
                    {
                        elemento.TipoCxc = bool.Parse(TipoCxc);
                    }
                    catch { }
                    elemento.eliminado = false;

                    int res = -1;

                    res = Logica.PutTipoCobros(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelTipoCobros(string id_tcob, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelTipoCobros(int.Parse(id_tcob), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tipos de Folios Externos

        [WebGet]
        [OperationContract]
        public string GetTipoFolios(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    TipoFolio elemento = new TipoFolio();
                    elemento.id_tipo = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetTipoFolios(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutTipoFolios(string id_tipo, string cod_tipo, string desc_tipo, string cuenta_casa, string limite_credito
            , string numero_credito, string inactiva_si_factura, string id_mone, string id_cuenta, string id_dcto, string eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    TipoFolio elemento = new TipoFolio();
                    try
                    {
                        elemento.id_tipo = int.Parse(id_tipo);
                    }
                    catch
                    {
                        elemento.id_tipo = 0;
                    }
                    elemento.cod_tipo = short.Parse(cod_tipo);
                    elemento.desc_tipo = desc_tipo;
                    elemento.cuenta_casa = false;
                    try
                    {
                        elemento.cuenta_casa = bool.Parse(cuenta_casa);
                    }
                    catch { }
                    elemento.limite_credito = double.Parse(limite_credito);
                    elemento.numero_credito = short.Parse(numero_credito);
                    elemento.inactiva_si_factura = false;
                    try
                    {
                        elemento.inactiva_si_factura = bool.Parse(inactiva_si_factura);
                    }
                    catch { }
                    elemento.id_mone = int.Parse(id_mone);
                    try
                    {
                        elemento.id_cuenta = int.Parse(id_cuenta);
                    }
                    catch
                    {
                        elemento.id_cuenta = 0;
                    }
                    try
                    {
                        elemento.id_dcto = int.Parse(id_dcto);
                    }
                    catch
                    {
                        elemento.id_dcto = 0;
                    }
                    elemento.eliminado = false;

                    int res = -1;

                    res = Logica.PutTipoFolios(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelTipoFolios(string id_tipo, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelTipoFolios(int.Parse(id_tipo), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tipos de Folios Externos - Impuestos

        [WebGet]
        [OperationContract]
        public string GetTipoFoliosImpuestos(string id_tipo, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetTipoFoliosImpuestos(int.Parse(id_tipo), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutTipoFoliosImpuestos(string id_tipo, string id_impu, string eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    TipoFolioImpuesto elemento = new TipoFolioImpuesto();
                    try
                    {
                        elemento.id_tipo = int.Parse(id_tipo);
                    }
                    catch
                    {
                        elemento.id_tipo = 0;
                    }
                    elemento.id_tipo = int.Parse(id_tipo);
                    elemento.id_impu = int.Parse(id_impu);
                    elemento.eliminado = false;


                    int res = -1;

                    res = Logica.PutTipoFoliosImpuestos(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelTipoFoliosImpuestos(string id_tipo, string id_impu, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelTipoFoliosImpuestos(int.Parse(id_tipo), int.Parse(id_impu), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Configuración de Auditoría Nocturna - Reset

        [WebGet]
        [OperationContract]
        public string ResetConfigAuditoria(string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.ResetConfigAuditoria(iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Configuración de Auditoría Nocturna - Generales

        [WebGet]
        [OperationContract]
        public string GetConfigCierre(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Hiddens.ConfigCierre(iden);
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutConfigCierre(string id_tabl, string dias_cierre, string asto_automatico, string integra_asiento, string prt_name, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ConfigCierre elemento = new ConfigCierre();
                    try
                    {
                        elemento.id_tabl = int.Parse(id_tabl);
                    }
                    catch
                    {
                        elemento.id_tabl = 0;
                    }
                    elemento.dias_cierre = int.Parse(dias_cierre);
                    try
                    {
                        elemento.asto_automatico = int.Parse(asto_automatico) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.asto_automatico = false;
                    }
                    try
                    {
                        elemento.integra_asiento = int.Parse(integra_asiento) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.integra_asiento = false;
                    }
                    elemento.prt_name = prt_name;

                    int res = -1;

                    res = Logica.PutConfigCierre(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Configuración de Auditoria Nocturna - Procesos

        [WebGet]
        [OperationContract]
        public string GetConfigAuditoria(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    ConfigAuditoria elemento = new ConfigAuditoria();
                    elemento.id_zcfg = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetConfigAuditoria(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutConfigAuditoria(string id_zcfg, string activa, string desc_opc, string orden_ejec
            , string sistema, string obligatoria, string reporte, string codigo_opc, string imprime
            , string copias, string config_form, string configuracion, string command_line
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ConfigAuditoria elemento = new ConfigAuditoria();
                    try
                    {
                        elemento.id_zcfg = int.Parse(id_zcfg);
                    }
                    catch
                    {
                        elemento.id_zcfg = 0;
                    }
                    elemento.activa = activa.Equals("True") ? true : false;
                    elemento.desc_opc = desc_opc;
                    elemento.orden_ejec = int.Parse(orden_ejec);
                    elemento.sistema = false;
                    try
                    {
                        elemento.sistema = bool.Parse(sistema);
                    }
                    catch { }
                    elemento.obligatoria = false;
                    try
                    {
                        elemento.obligatoria = bool.Parse(obligatoria);
                    }
                    catch { }
                    elemento.reporte = false;
                    try
                    {
                        elemento.reporte = bool.Parse(reporte);
                    }
                    catch { }
                    elemento.codigo_opc = codigo_opc;
                    try
                    {
                        elemento.imprime = int.Parse(imprime) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.imprime = false;
                    }
                    elemento.copias = int.Parse(copias);
                    elemento.config_form = 0;
                    elemento.configuracion = "";
                    elemento.command_line = String.IsNullOrEmpty(command_line) ? "" : command_line;


                    int res = -1;

                    res = Logica.PutConfigAuditoria(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelConfigAuditoria(string id_zcfg, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelConfigAuditoria(int.Parse(id_zcfg), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Configuración de Auditoria Nocturna - Informes

        [WebGet]
        [OperationContract]
        public string GetListadosFoliosAbiertos(string modo, string id_zcfg, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    DataTable dt;

                    switch (int.Parse(modo))
                    {
                        case 1:
                            dt = Utils.GetListadoLFA(iden);
                            break;
                        case 2:
                            dt = Utils.GetListadoLFAG();
                            break;
                        case 3:
                            dt = Utils.GetListadoLFAT();
                            break;
                        default:
                            dt = Utils.GetListadoLFA(iden);
                            break;
                    }

                    string configuracion = "";
                    int orden = 0;
                    string incluir = "False";

                    try
                    {
                        ConfigAuditoria caud = Logica.GetConfigAuditoria(int.Parse(id_zcfg), false, iden);
                        configuracion = caud.configuracion.Split(',')[0];
                        orden = int.Parse(caud.configuracion.Split(',')[(int.Parse(modo) == 3 || int.Parse(modo) == 2 ? 1 : 2)]);
                        incluir = int.Parse(caud.configuracion.Split(',')[(int.Parse(modo) == 3 ? 2 : 1)]) == 1 ? "True" : "False";
                    }
                    catch { }

                    if (configuracion.Length > 0)
                    {
                        DataTable dt2 = new DataTable();
                        dt2.Columns.Add(new DataColumn("Id"));
                        dt2.Columns.Add(new DataColumn("Codigo"));
                        dt2.Columns.Add(new DataColumn("Descripcion"));
                        dt2.Columns.Add(new DataColumn("Marcado"));
                        dt2.Columns.Add(new DataColumn("Bloqueado"));
                        dt2.Columns.Add(new DataColumn("Eliminado"));
                        dt2.Columns.Add(new DataColumn("Orden"));
                        dt2.Columns.Add(new DataColumn("Incluir"));


                        DataRow drn;

                        int i = 0;
                        foreach (string elem in configuracion.Split(';'))
                        {
                            drn = dt2.NewRow();
                            drn["Id"] = dt.Rows[i]["Id"];
                            drn["Codigo"] = dt.Rows[i]["Codigo"];
                            drn["Descripcion"] = dt.Rows[i]["Descripcion"];
                            try
                            {
                                drn["Marcado"] = int.Parse(elem) == 1 ? "True" : "False";
                            }
                            catch
                            {
                                drn["Marcado"] = dt.Rows[i]["Marcado"];
                            }
                            drn["Bloqueado"] = dt.Rows[i]["Bloqueado"];
                            drn["Eliminado"] = "False";
                            drn["Orden"] = orden;
                            drn["Incluir"] = incluir;
                            dt2.Rows.Add(drn);
                            i += 1;
                        }

                        return Globals.jqGridGenie.DataTableToJQGridJSON(dt2);
                    }
                    else
                    {
                        return Globals.jqGridGenie.DataTableToJQGridJSON(dt);
                    }
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutListadosFoliosAbiertos(string modo, string id_zcfg, string elementos, string orden, string incluir, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    string configuracion = "";

                    int vincluir = 0;
                    try
                    {
                        vincluir = int.Parse(incluir);
                    }
                    catch { }

                    int i = 1;

                    List<int> opciones = new List<int>();

                    foreach (string e in elementos.Split(','))
                    {
                        opciones.Add(int.Parse(e));
                    }

                    opciones.Sort();

                    foreach (int j in opciones)
                    {
                        while (i <= j)
                        {
                            if (i == 1)
                            {
                                configuracion += "1";
                            }
                            else if (i == j && i != 1)
                            {
                                configuracion += ";1";
                            }
                            else
                            {
                                configuracion += ";0";
                            }
                            i++;
                        }
                    }

                    switch (int.Parse(modo))
                    {
                        case 1:
                            configuracion += ", 3," + orden;
                            break;
                        case 2:
                            configuracion += "," + orden;
                            break;
                        case 3:
                            configuracion += "," + orden + "," + vincluir;
                            break;
                    }

                    int res = -1;

                    res = Logica.PutListadosFoliosAbiertos(int.Parse(id_zcfg), configuracion, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Temporadas

        [WebGet]
        [OperationContract]
        public string GetTemporadas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Temporada elemento = new Temporada();
                    elemento.id_temp = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetTemporadas(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutTemporadas(string id_temp, string desc_temp, string eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Temporada elemento = new Temporada();
                    try
                    {
                        elemento.id_temp = int.Parse(id_temp);
                    }
                    catch
                    {
                        elemento.id_temp = 0;
                    }
                    elemento.desc_temp = desc_temp;
                    elemento.eliminado = false;


                    int res = -1;

                    res = Logica.PutTemporadas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelTemporadas(string id_temp, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelTemporadas(int.Parse(id_temp), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Temporadas - Periodos

        [WebGet]
        [OperationContract]
        public string GetPeriodos(string id_temp, string Activos, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool activos = false;
                    try
                    {
                        activos = int.Parse(Activos) == 0 ? false : true;
                    }
                    catch { }

                    return CrazyGenie.DateHourCleaner(Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPeriodos(int.Parse(id_temp), activos, iden)));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPeriodos(string id_peri, string id_temp, string fecha_desde, string fecha_hasta, string id_ttem, string id_plazoini, string porc_ini, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Periodo elemento = new Periodo();
                    try
                    {
                        elemento.id_peri = int.Parse(id_peri);
                    }
                    catch
                    {
                        elemento.id_peri = 0;
                    }
                    elemento.id_temp = int.Parse(id_temp);
                    elemento.fecha_desde = DateTime.Parse(fecha_desde);
                    elemento.fecha_hasta = DateTime.Parse(fecha_hasta);
                    elemento.id_ttem = int.Parse(id_ttem);
                    elemento.id_plazoini = int.Parse(id_plazoini);
                    elemento.porc_ini = float.Parse(porc_ini);


                    int res = -1;

                    res = Logica.PutPeriodos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelPeriodos(string id_peri, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelPeriodos(int.Parse(id_peri), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Temporadas - Periodos - Plazos Iniciales

        [WebGet]
        [OperationContract]
        public string GetPeriodoPlazos(string id_peri, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPeriodoPlazos(int.Parse(id_peri), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPeriodoPlazos(string id_plazo, string id_peri, string desde_fec_rese, string dias, string porciento, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    PeriodoPlazo elemento = new PeriodoPlazo();
                    try
                    {
                        elemento.id_plazo = int.Parse(id_plazo);
                    }
                    catch
                    {
                        elemento.id_plazo = 0;
                    }
                    elemento.id_peri = int.Parse(id_peri);
                    elemento.desde_fec_rese = bool.Parse(desde_fec_rese);
                    elemento.dias = short.Parse(dias);
                    elemento.porciento = float.Parse(porciento);


                    int res = -1;

                    res = Logica.PutPeriodoPlazos(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelPeriodoPlazos(string id_plazo, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelPeriodoPlazos(int.Parse(id_plazo), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tarifas (Contratos)

        [WebGet]
        [OperationContract]
        public string GetContrato(string id_cont, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Contrato elemento = Logica.GetContratos(int.Parse(id_cont), false, true, iden);

                    return "<input type='hidden' id='HIDCON_id_cont' value='" + elemento.id_cont + "' />" +
                           "<input type='hidden' id='HIDCON_contrato' value='" + elemento.contrato + "' />" +
                           "<input type='hidden' id='HIDCON_desc_cont' value='" + elemento.desc_cont + "' />" +
                           "<input type='hidden' id='HIDCON_id_naci' value='" + elemento.id_naci + "' />" +
                           "<input type='hidden' id='HIDCON_id_agen' value='" + elemento.id_agen + "' />" +
                           "<input type='hidden' id='HIDCON_id_merc' value='" + elemento.id_merc + "' />" +
                           "<input type='hidden' id='HIDCON_id_dcto' value='" + elemento.id_dcto + "' />" +
                           "<input type='hidden' id='HIDCON_id_temp' value='" + elemento.id_temp + "' />" +
                           "<input type='hidden' id='HIDCON_id_mone' value='" + elemento.id_mone + "' />" +
                           "<input type='hidden' id='HIDCON_tasa_fija' value='" + elemento.tasa_fija + "' />" +
                           "<input type='hidden' id='HIDCON_dega_oblig' value='" + elemento.dega_oblig + "' />" +
                           "<input type='hidden' id='HIDCON_frec_sabana' value='" + elemento.frec_sabana + "' />" +
                           "<input type='hidden' id='HIDCON_id_cuenta' value='" + elemento.id_cuenta + "' />" +
                           "<input type='hidden' id='HIDCON_max_dias' value='" + elemento.max_dias + "' />" +
                           "<input type='hidden' id='HIDCON_max_saldo' value='" + elemento.max_saldo + "' />" +
                           "<input type='hidden' id='HIDCON_id_cardex' value='" + elemento.id_cardex + "' />" +
                           "<input type='hidden' id='HIDCON_observ' value='" + elemento.observ + "' />" +
                           "<input type='hidden' id='HIDCON_TipoContrato' value='" + elemento.TipoContrato + "' />" +
                           "<input type='hidden' id='HIDCON_id_plnt' value='" + elemento.id_plnt + "' />" +
                           "<input type='hidden' id='HIDCON_eliminado' value='" + elemento.eliminado + "' />";
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetContratos(string Eliminado, string Fil_Codigo, string vFil_Codigo, string Fil_Descripcion, string vFil_Descripcion
            , string Fil_Empresa, string vFil_Empresa, string Fil_Mercado, string vFil_Mercado, string Fil_Moneda, string vFil_Moneda
            , string Fil_Nacionalidad, string vFil_Nacionalidad, string Fil_Temporada, string vFil_Temporada
            , string Fil_Plantilla, string vFil_Plantilla, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Contrato elemento = new Contrato();
                    elemento.id_cont = 0;

                    ContratoFiltro elemento2 = new ContratoFiltro();
                    elemento2.Fil_Codigo = false;
                    try
                    {
                        elemento2.Fil_Codigo = int.Parse(Fil_Codigo) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Codigo = vFil_Codigo;
                    elemento2.Fil_Descripcion = false;
                    try
                    {
                        elemento2.Fil_Descripcion = int.Parse(Fil_Descripcion) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Descripcion = vFil_Descripcion;
                    elemento2.Fil_Empresa = false;
                    try
                    {
                        elemento2.Fil_Empresa = int.Parse(Fil_Empresa) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Empresa = int.Parse(vFil_Empresa);
                    elemento2.Fil_Mercado = false;
                    try
                    {
                        elemento2.Fil_Mercado = int.Parse(Fil_Mercado) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Mercado = int.Parse(vFil_Mercado);
                    elemento2.Fil_Moneda = false;
                    try
                    {
                        elemento2.Fil_Moneda = int.Parse(Fil_Moneda) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Moneda = int.Parse(vFil_Moneda);
                    elemento2.Fil_Nacionalidad = false;
                    try
                    {
                        elemento2.Fil_Nacionalidad = int.Parse(Fil_Nacionalidad) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Nacionalidad = int.Parse(vFil_Nacionalidad);
                    elemento2.Fil_Temporada = false;
                    try
                    {
                        elemento2.Fil_Temporada = int.Parse(Fil_Temporada) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Temporada = int.Parse(vFil_Temporada);
                    elemento2.Fil_Plantilla = false;
                    try
                    {
                        elemento2.Fil_Plantilla = int.Parse(Fil_Plantilla) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Plantilla = int.Parse(vFil_Plantilla);

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetContratos(elemento, elemento2, true, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutContratos(string id_cont, string contrato, string desc_cont, string id_naci, string id_agen, string id_merc, string id_dcto, string id_temp
            , string id_mone, string tasa_fija, string dega_oblig, string frec_sabana, string id_cuenta, string max_dias, string max_saldo, string id_cardex
            , string observ, string TipoContrato, string id_plnt, string eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Contrato elemento = new Contrato();
                    try
                    {
                        elemento.id_cont = int.Parse(id_cont);
                    }
                    catch
                    {
                        elemento.id_cont = 0;
                    }
                    elemento.contrato = contrato;
                    elemento.desc_cont = desc_cont;
                    elemento.id_naci = int.Parse(id_naci);
                    elemento.id_agen = int.Parse(id_agen);
                    elemento.id_merc = int.Parse(id_merc);
                    elemento.id_dcto = int.Parse(id_dcto);
                    elemento.id_temp = int.Parse(id_temp);
                    elemento.id_mone = int.Parse(id_mone);
                    elemento.tasa_fija = float.Parse(tasa_fija);
                    try
                    {
                        elemento.dega_oblig = int.Parse(dega_oblig) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.dega_oblig = false;
                    }
                    elemento.frec_sabana = short.Parse(frec_sabana);
                    elemento.id_cuenta = int.Parse(id_cuenta);
                    elemento.max_dias = short.Parse(max_dias);
                    elemento.max_saldo = double.Parse(max_saldo);
                    elemento.id_cardex = int.Parse(id_cardex);
                    elemento.observ = observ;
                    try
                    {
                        elemento.TipoContrato = int.Parse(TipoContrato) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.TipoContrato = false;
                    }
                    elemento.id_plnt = int.Parse(id_plnt);
                    elemento.eliminado = false;

                    int res = -1;

                    res = Logica.PutContratos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelContratos(string id_cont, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelContratos(int.Parse(id_cont), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tarifas (Contratos) - Precios de Empresa

        [WebGet]
        [OperationContract]
        public string GetContratoPreciosEmpresa(string id_cont, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetContratoPreciosEmpresa(int.Parse(id_cont), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutContratoPreciosEmpresa(string id_ccon, string id_cont, string id_cfag, string porpax
            , string factor_div, string automatico, string Detalles, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ContratoPrecioEmpresa elemento = new ContratoPrecioEmpresa();
                    try
                    {
                        elemento.id_ccon = int.Parse(id_ccon);
                    }
                    catch
                    {
                        elemento.id_ccon = 0;
                    }
                    elemento.id_cont = int.Parse(id_cont);
                    elemento.id_cfag = int.Parse(id_cfag);
                    elemento.porpax = false;
                    try
                    {
                        elemento.porpax = bool.Parse(porpax);
                    }
                    catch { }
                    elemento.factor_div = short.Parse(factor_div);
                    elemento.automatico = false;
                    try
                    {
                        elemento.automatico = bool.Parse(automatico);
                    }
                    catch { }

                    DataTable dt = jqGridGenie.JQGridJSONToDataTable(Detalles);

                    int res = -1;

                    res = Logica.PutContratoPreciosEmpresa(elemento, dt, iden);

                    //return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelContratoPreciosEmpresa(string id_ccon, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelContratoPreciosEmpresa(int.Parse(id_ccon), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tarifas (Contratos) - Precios de Empresa - Detalle

        [WebGet]
        [OperationContract]
        public string GetContratoPreciosAgenciaDet(string id_ccon, string id_temp, string activos, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Activos = false;
                    try
                    {
                        Activos = int.Parse(activos) == 0 ? false : true;
                    }
                    catch { }

                    return CrazyGenie.DateHourCleaner(Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetContratoPreciosAgenciaDet(int.Parse(id_ccon), int.Parse(id_temp), Activos, iden)));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Tarifas (Contratos) - Precios de Directos

        [WebGet]
        [OperationContract]
        public string GetContratoPreciosDirecto(string id_cont, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetContratoPreciosDirecto(int.Parse(id_cont), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutContratoPreciosDirecto(string id_conh, string id_cont, string id_uhab
            , string Detalles, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ContratoPrecioDirecto elemento = new ContratoPrecioDirecto();
                    try
                    {
                        elemento.id_conh = int.Parse(id_conh);
                    }
                    catch
                    {
                        elemento.id_conh = 0;
                    }
                    elemento.id_cont = int.Parse(id_cont);
                    elemento.id_uhab = short.Parse(id_uhab);

                    DataTable dt = jqGridGenie.JQGridJSONToDataTable(Detalles);


                    int res = -1;

                    res = Logica.PutContratoPreciosDirecto(elemento, dt, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelContratoPreciosDirecto(string id_conh, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelContratoPreciosDirecto(int.Parse(id_conh), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tarifas (Contratos) - Precios de Directos - Detalle

        [WebGet]
        [OperationContract]
        public string GetContratoPreciosDirectoDet(string id_conh, string id_temp, string activos, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Activos = false;
                    try
                    {
                        Activos = int.Parse(activos) == 0 ? false : true;
                    }
                    catch { }

                    return CrazyGenie.DateHourCleaner(Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetContratoPreciosDirectoDet(int.Parse(id_conh), int.Parse(id_temp), Activos, iden)));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tarifas (Contratos) - Release

        [WebGet]
        [OperationContract]
        public string GetContratoRelease(string id_cont, string Activo, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Activos = false;
                    try
                    {
                        Activos = int.Parse(Activo) == 0 ? false : true;
                    }
                    catch { }

                    return CrazyGenie.DateHourCleaner(Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetContratoRelease(int.Parse(id_cont), Activos, iden)));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutContratoRelease(string id_crel, string id_cont, string id_peri, string release, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ContratoRelease elemento = new ContratoRelease();
                    elemento.id_crel = 0;
                    elemento.id_cont = int.Parse(id_cont);
                    elemento.id_peri = int.Parse(id_peri);
                    elemento.release = short.Parse(release);

                    int res = -1;

                    res = Logica.PutContratoRelease(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelContratoRelease(string id_cont, string id_peri, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelContratoRelease(int.Parse(id_cont), int.Parse(id_peri), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tarifas (Contratos) - Impuestos

        [WebGet]
        [OperationContract]
        public string GetContratoImpuestos(string id_cont, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetContratoImpuestos(int.Parse(id_cont), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutContratoImpuestos(string id_cont, string id_impu, string incluido, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ContratoImpuesto elemento = new ContratoImpuesto();
                    try
                    {
                        elemento.id_cont = int.Parse(id_cont);
                    }
                    catch
                    {
                        elemento.id_cont = 0;
                    }
                    elemento.id_cont = int.Parse(id_cont);
                    elemento.id_impu = int.Parse(id_impu);
                    elemento.incluido = false;
                    try
                    {
                        elemento.incluido = bool.Parse(incluido);
                    }
                    catch { }

                    int res = -1;

                    res = Logica.PutContratoImpuestos(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelContratoImpuestos(string id_cont, string id_impu, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelContratoImpuestos(int.Parse(id_cont), int.Parse(id_impu), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Tarifas (Contratos) - Compartir Cupos

        [WebGet]
        [OperationContract]
        public string GetContratoCupos(string id_conh, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return CrazyGenie.DateHourCleaner(Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetContratoCupos(int.Parse(id_conh), iden)));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutContratoCupos(string id_cual, string id_conh, string id_peri, string descripcion, string id_cont_dest, string id_conh_dest, string fecha_desde, string fecha_hasta, string cant_hab, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ContratoCupo elemento = new ContratoCupo();
                    try
                    {
                        elemento.id_cual = int.Parse(id_cual);
                    }
                    catch
                    {
                        elemento.id_cual = 0;
                    }
                    elemento.id_conh = int.Parse(id_conh);
                    elemento.id_peri = int.Parse(id_peri);
                    elemento.descripcion = descripcion;
                    elemento.id_cont_dest = int.Parse(id_cont_dest);
                    elemento.id_conh_dest = int.Parse(id_conh_dest);
                    elemento.fecha_desde = DateTime.Parse(fecha_desde);
                    elemento.fecha_hasta = DateTime.Parse(fecha_hasta);
                    elemento.cant_hab = int.Parse(cant_hab);

                    int res = -1;

                    res = Logica.PutContratoCupos(elemento, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelContratoCupos(string id_cual, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelContratoCupos(int.Parse(id_cual), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Tarifas (Contratos) - Duplicar

        [WebGet]
        [OperationContract]
        public string DuplicarContrato(string id_cont_ori, string contrato_dest, string desc_cont_dest, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DuplicarContrato(int.Parse(id_cont_ori), contrato_dest, desc_cont_dest, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Tarifas (Contratos) - Cambio de Tasas a Contratos por Moneda

        [WebGet]
        [OperationContract]
        public string GetContratoTasas(string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetContratoTasas(iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutContratoTasas(string Datos, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {

                    DataTable dt = jqGridGenie.JQGridJSONToDataTable(Datos);

                    int res = -1;

                    res = Logica.PutContratoTasas(dt, iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Tarifas (Contratos) - Generar

        [WebGet]
        [OperationContract]
        public string PutTarifasGenerar(string id_cont, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {

                    int res = 0;

                    res = Logica.PutTarifasGenerar(int.Parse(id_cont), iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Plantillas

        [WebGet]
        [OperationContract]
        public string GetPlantilla(string id_plnt, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Plantilla elemento = Logica.GetPlantillas(int.Parse(id_plnt), false, true, iden);

                    return "<input type='hidden' id='HIDCON_id_plnt' value='" + elemento.id_plnt + "' />" +
                           "<input type='hidden' id='HIDCON_id_temp' value='" + elemento.id_temp + "' />" +
                           "<input type='hidden' id='HIDCON_id_mone' value='" + elemento.id_mone + "' />" +
                           "<input type='hidden' id='HIDCON_cod_plnt' value='" + elemento.cod_plnt + "' />" +
                           "<input type='hidden' id='HIDCON_desc_plnt' value='" + elemento.desc_plnt + "' />" +
                           "<input type='hidden' id='HIDCON_directo' value='" + (elemento.directo == true ? "1" : "0") + "' />" +
                           "<input type='hidden' id='HIDCON_eliminado' value='" + elemento.eliminado + "' />";
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetPlantillas(string Eliminado, string Fil_Codigo, string vFil_Codigo, string Fil_Descripcion, string vFil_Descripcion
            , string Fil_Moneda, string vFil_Moneda, string Fil_Temporada, string vFil_Temporada, string Dominio
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Plantilla elemento = new Plantilla();
                    elemento.id_plnt = 0;

                    PlantillaFiltro elemento2 = new PlantillaFiltro();
                    elemento2.Fil_Codigo = false;
                    try
                    {
                        elemento2.Fil_Codigo = int.Parse(Fil_Codigo) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Codigo = vFil_Codigo;
                    elemento2.Fil_Descripcion = false;
                    try
                    {
                        elemento2.Fil_Descripcion = int.Parse(Fil_Descripcion) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Descripcion = vFil_Descripcion;
                    elemento2.Fil_Moneda = false;
                    try
                    {
                        elemento2.Fil_Moneda = int.Parse(Fil_Moneda) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Moneda = int.Parse(vFil_Moneda);
                    elemento2.Fil_Temporada = false;
                    try
                    {
                        elemento2.Fil_Temporada = int.Parse(Fil_Temporada) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_Temporada = int.Parse(vFil_Temporada);

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPlantillas(elemento, elemento2, true, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPlantillas(string id_plnt, string id_temp, string id_mone, string cod_plnt, string desc_plnt, string directo
            , string eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Plantilla elemento = new Plantilla();
                    try
                    {
                        elemento.id_plnt = int.Parse(id_plnt);
                    }
                    catch
                    {
                        elemento.id_plnt = 0;
                    }
                    elemento.id_temp = int.Parse(id_temp);
                    elemento.id_mone = int.Parse(id_mone);
                    elemento.cod_plnt = cod_plnt;
                    elemento.desc_plnt = desc_plnt;
                    try
                    {
                        elemento.directo = int.Parse(directo) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.directo = false;
                    }
                    elemento.eliminado = false;

                    int res = -1;

                    res = Logica.PutPlantillas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelPlantillas(string id_plnt, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelPlantillas(int.Parse(id_plnt), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Plantillas - Precios de Empresa

        [WebGet]
        [OperationContract]
        public string GetPlantillaPreciosEmpresa(string id_plnt, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPlantillaPreciosEmpresa(int.Parse(id_plnt), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPlantillaPreciosEmpresa(string id_pcon, string id_plnt, string id_cfag, string porpax
            , string factor_div, string automatico, string Detalles, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    PlantillaPrecioEmpresa elemento = new PlantillaPrecioEmpresa();
                    try
                    {
                        elemento.id_pcon = int.Parse(id_pcon);
                    }
                    catch
                    {
                        elemento.id_pcon = 0;
                    }
                    elemento.id_plnt = int.Parse(id_plnt);
                    elemento.id_cfag = int.Parse(id_cfag);
                    elemento.porpax = false;
                    try
                    {
                        elemento.porpax = bool.Parse(porpax);
                    }
                    catch { }
                    elemento.factor_div = short.Parse(factor_div);
                    elemento.automatico = false;
                    try
                    {
                        elemento.automatico = bool.Parse(automatico);
                    }
                    catch { }

                    DataTable dt = jqGridGenie.JQGridJSONToDataTable(Detalles);

                    int res = -1;

                    res = Logica.PutPlantillaPreciosEmpresa(elemento, dt, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelPlantillaPreciosEmpresa(string id_pcon, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelPlantillaPreciosEmpresa(int.Parse(id_pcon), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Plantillas - Precios de Empresa - Detalle

        [WebGet]
        [OperationContract]
        public string GetPlantillaPreciosAgenciaDet(string id_pcon, string id_temp, string activos, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Activos = false;
                    try
                    {
                        Activos = int.Parse(activos) == 0 ? false : true;
                    }
                    catch { }

                    return CrazyGenie.DateHourCleaner(Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPlantillaPreciosAgenciaDet(int.Parse(id_pcon), int.Parse(id_temp), Activos, iden)));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Plantillas - Precios de Directos

        [WebGet]
        [OperationContract]
        public string GetPlantillaPreciosDirecto(string id_plnt, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPlantillaPreciosDirecto(int.Parse(id_plnt), iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPlantillaPreciosDirecto(string id_ponh, string id_plnt, string id_uhab
            , string Detalles, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    PlantillaPrecioDirecto elemento = new PlantillaPrecioDirecto();
                    try
                    {
                        elemento.id_ponh = int.Parse(id_ponh);
                    }
                    catch
                    {
                        elemento.id_ponh = 0;
                    }
                    elemento.id_plnt = int.Parse(id_plnt);
                    elemento.id_uhab = short.Parse(id_uhab);

                    DataTable dt = jqGridGenie.JQGridJSONToDataTable(Detalles);


                    int res = -1;

                    res = Logica.PutPlantillaPreciosDirecto(elemento, dt, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string DelPlantillaPreciosDirecto(string id_ponh, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DelPlantillaPreciosDirecto(int.Parse(id_ponh), iden);

                    return res != -2147483647 ? "1" : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Plantillas - Precios de Directos - Detalle

        [WebGet]
        [OperationContract]
        public string GetPlantillaPreciosDirectoDet(string id_ponh, string id_temp, string activos, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Activos = false;
                    try
                    {
                        Activos = int.Parse(activos) == 0 ? false : true;
                    }
                    catch { }

                    return CrazyGenie.DateHourCleaner(Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPlantillaPreciosDirectoDet(int.Parse(id_ponh), int.Parse(id_temp), Activos, iden)));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Plantillas - Duplicar

        [WebGet]
        [OperationContract]
        public string DuplicarPlantilla(string id_plnt_ori, string cod_plnt_dest, string desc_plnt_dest, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int res = -1;

                    res = Logica.DuplicarPlantilla(int.Parse(id_plnt_ori), cod_plnt_dest, desc_plnt_dest, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Plantillas - Generar

        [WebGet]
        [OperationContract]
        public string PutPlantillasGenerar(string id_plnt, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {

                    int res = 0;

                    res = Logica.PutPlantillasGenerar(int.Parse(id_plnt), iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Plantillas - Generar Precios

        [WebGet]
        [OperationContract]
        public string PutPlantillasGenerarPrecios(string id_plnt, string Modo, string id_thab, string PrecAdultos, string PrecNinos, string id_cfag, string PrecCfag
            , string id_peri_ini, string id_peri_fin, string id_ttem, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {

                    int res = 0;

                    float PrecAd = 0;
                    try
                    {
                        PrecAd = float.Parse(PrecAdultos);
                    }
                    catch { }

                    float PrecNin = 0;
                    try
                    {
                        PrecNin = float.Parse(PrecNinos);
                    }
                    catch { }

                    float PrecCF = 0;
                    try
                    {
                        PrecCF = float.Parse(PrecCfag);
                    }
                    catch { }

                    int i_id_cfag = 0;

                    try 
                    { 
                        i_id_cfag = int.Parse(id_cfag);
                    }
                    catch { }

                    res = Logica.PutPlantillasGenerarPrecios(int.Parse(id_plnt), int.Parse(Modo) == 1 ? true : false
                        , int.Parse(id_thab), PrecAd, PrecNin, i_id_cfag, PrecCF
                        , int.Parse(id_peri_ini), int.Parse(id_peri_fin), int.Parse(id_ttem), iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Plantillas - Actualizar

        [WebGet]
        [OperationContract]
        public string PutPlantillasActualizar(string id_plnt, string id_cont, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {

                    int res = 0;

                    res = Logica.PutPlantillasActualizar(int.Parse(id_plnt), int.Parse(id_cont), iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUnauthorizedUser");
                }
                else
                {
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Periodos

        [WebGet]
        [OperationContract]
        public string GetPeriodosFecHotelCombo(string Modo, string id_temp, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return HTMLSelects.PeriodosFecHotelComboOptions(int.Parse(Modo) == 1 ? true : false, int.Parse(id_temp), "", 0, 0, iden);
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Perfiles (Cardex)

        [WebGet]
        [OperationContract]
        public string GetPerfiles(string Modo, string id_cardex, string id_cardex_fil, string Fil_nombre, string vFil_nombre, string Fil_clave_cardex, string vFil_clave_cardex
            , string Fil_dni_cif, string vFil_dni_cif, string Fil_provincia, string vFil_provincia, string Fil_ciudad, string vFil_ciudad
            , string Fil_localidad, string vFil_localidad, string Fil_zip_code, string vFil_zip_code, string Fil_id_naci, string vFil_id_naci
            , string Fil_fecha_nac, string Fil_fecha_nac_modo, string vFil_fecha_nac, string vFil_fecha_nac2
            , string Fil_vip, string vFil_vip, string Fil_sexo, string vFil_sexo
            , string Fil_cumpleanos, string vFil_cumpleanos, string vFil_cumpleanos2
            , string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Perfil elemento = new Perfil();
                    elemento.id_cardex = int.Parse(id_cardex);

                    PerfilFiltro elemento2 = new PerfilFiltro();
                    elemento2.id_cardex_fil = 0;
                    try
                    {
                        elemento2.id_cardex_fil = int.Parse(id_cardex_fil);
                    }
                    catch { }
                    elemento2.Fil_nombre = false;
                    try
                    {
                        elemento2.Fil_nombre = int.Parse(Fil_nombre) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_nombre = vFil_nombre;
                    elemento2.Fil_clave_cardex = false;
                    try
                    {
                        elemento2.Fil_clave_cardex = int.Parse(Fil_clave_cardex) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_clave_cardex = vFil_clave_cardex;
                    elemento2.Fil_dni_cif = false;
                    try
                    {
                        elemento2.Fil_dni_cif = int.Parse(Fil_dni_cif) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_dni_cif = vFil_dni_cif;
                    elemento2.Fil_provincia = false;
                    try
                    {
                        elemento2.Fil_provincia = int.Parse(Fil_provincia) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_provincia = vFil_provincia;
                    elemento2.Fil_ciudad = false;
                    try
                    {
                        elemento2.Fil_ciudad = int.Parse(Fil_ciudad) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_ciudad = vFil_ciudad;
                    elemento2.Fil_localidad = false;
                    try
                    {
                        elemento2.Fil_localidad = int.Parse(Fil_localidad) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_localidad = vFil_localidad;
                    elemento2.Fil_zip_code = false;
                    try
                    {
                        elemento2.Fil_zip_code = int.Parse(Fil_zip_code) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_zip_code = vFil_zip_code;
                    elemento2.Fil_id_naci = false;
                    try
                    {
                        elemento2.Fil_id_naci = int.Parse(Fil_id_naci) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_id_naci = int.Parse(vFil_id_naci);
                    elemento2.Fil_fecha_nac = false;
                    try
                    {
                        elemento2.Fil_fecha_nac = int.Parse(Fil_fecha_nac) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.Fil_fecha_nac_modo = int.Parse(Fil_fecha_nac_modo);
                    try
                    {
                        elemento2.vFil_fecha_nac = DateTime.Parse(vFil_fecha_nac);
                    }
                    catch
                    {
                        elemento2.vFil_fecha_nac = DateTime.Now;
                    }
                    try
                    {
                        elemento2.vFil_fecha_nac2 = DateTime.Parse(vFil_fecha_nac2);
                    }
                    catch
                    {
                        elemento2.vFil_fecha_nac2 = DateTime.Now;
                    }
                    elemento2.Fil_vip = false;
                    try
                    {
                        elemento2.Fil_vip = int.Parse(Fil_vip) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_vip = false;
                    elemento2.Fil_sexo = false;
                    try
                    {
                        elemento2.Fil_sexo = int.Parse(Fil_sexo) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.vFil_sexo = false;
                    try
                    {
                        elemento2.vFil_sexo = int.Parse(vFil_sexo) == 1 ? true : false;
                    }
                    catch { }
                    elemento2.Fil_cumpleanos = false;
                    try
                    {
                        elemento2.Fil_cumpleanos = int.Parse(Fil_cumpleanos) == 1 ? true : false;
                    }
                    catch { }
                    try
                    {
                        elemento2.vFil_cumpleanos = DateTime.Parse(vFil_cumpleanos);
                    }
                    catch
                    {
                        elemento2.vFil_cumpleanos = DateTime.Now;
                    }
                    try
                    {
                        elemento2.vFil_cumpleanos2 = DateTime.Parse(vFil_cumpleanos2);
                    }
                    catch
                    {
                        elemento2.vFil_cumpleanos2 = DateTime.Now;
                    }

                    if (elemento.id_cardex == 0)
                    {
                        return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPerfiles(int.Parse(Modo), elemento, elemento2, Eliminados, iden).Tables[0]);
                    }
                    else
                    {
                        elemento = Logica.GetPerfiles(elemento.id_cardex, Eliminados, iden);

                        string hiddata = "";
                        hiddata += "<input type='hidden' id='HIDPER_id_cardex' value='" + elemento.id_cardex + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_es_empresa' value='" + (elemento.es_empresa ? 1 : 0) + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_id_mone' value='" + elemento.id_mone + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_id_cuenta' value='" + elemento.id_cuenta + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_id_dcto' value='" + elemento.id_dcto + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_clave_cardex' value='" + elemento.clave_cardex + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_direccion' value='" + elemento.direccion + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_fecha_nac' value='" + CrazyGenie.DateHourCleaner(elemento.fecha_nac.ToString()) + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_precio_especial' value='" + String.Format("{0:N2}", elemento.precio_especial) + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_empresa' value='" + (elemento.empresa ? 1 : 0) + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_dni_cif' value='" + elemento.dni_cif + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_vip' value='" + (elemento.vip ? 1 : 0) + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_E_mail' value='" + elemento.E_mail + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_localidad' value='" + elemento.localidad + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_ciudad' value='" + elemento.ciudad + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_zip_code' value='" + elemento.zip_code + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_provincia' value='" + elemento.provincia + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_observaciones' value='" + elemento.observaciones + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_id_naci' value='" + elemento.id_naci + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_id_idio' value='" + elemento.id_idio + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_telefonos' value='" + elemento.telefonos + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_fax' value='" + elemento.fax + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_referencia' value='" + elemento.referencia + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_siglas' value='" + elemento.siglas + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_nombre_empresa' value='" + elemento.nombre_empresa + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_objeto_social' value='" + elemento.objeto_social + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_nombre_gerente' value='" + elemento.nombre_gerente + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_nombre' value='" + elemento.nombre + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_lugar_nacimiento' value='" + elemento.lugar_nacimiento + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_profesion' value='" + elemento.profesion + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_tipo_doc' value='" + (elemento.tipo_doc ? 1 : 0) + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_sexo' value='" + (elemento.sexo ? 1 : 0) + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_venc_pas' value='" + CrazyGenie.DateHourCleaner(elemento.venc_pas.ToString()) + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_tarj_cred' value='" + elemento.tarj_cred + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_venc_tarj_month' value='" + elemento.venc_tarj.Month + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_venc_tarj_year' value='" + elemento.venc_tarj.Year + "' />";
                        hiddata += "<input type='hidden' id='HIDPER_Eliminado' value='" + elemento.eliminado + "' />";
                        return hiddata;
                    }
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPerfiles(string id_cardex, string es_empresa, string id_mone, string id_cuenta, string id_dcto, string clave_cardex
            , string direccion, string fecha_nac, string precio_especial, string empresa, string dni_cif, string vip, string E_mail, string localidad
            , string ciudad, string zip_code, string provincia, string observaciones, string id_naci, string id_idio, string telefonos, string fax
            , string referencia, string siglas, string nombre_empresa, string objeto_social, string nombre_gerente, string nombre, string lugar_nacimiento
            , string profesion, string tipo_doc, string sexo, string venc_pas, string tarj_cred, string venc_tarj_month, string venc_tarj_year
            , string numero_pas, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    DateTime FechaNula = new DateTime(1900, 1, 1);

                    Perfil elemento = new Perfil();
                    try
                    {
                        elemento.id_cardex = int.Parse(id_cardex);
                    }
                    catch
                    {
                        elemento.id_cardex = 0;
                    }
                    elemento.es_empresa = false;
                    try
                    {
                        elemento.es_empresa = int.Parse(es_empresa) == 1 ? true : false;
                    }
                    catch { }
                    elemento.id_mone = int.Parse(id_mone);
                    elemento.id_cuenta = int.Parse(id_cuenta);
                    elemento.id_dcto = int.Parse(id_dcto);
                    elemento.clave_cardex = clave_cardex;
                    elemento.direccion = direccion;
                    try
                    {
                        elemento.fecha_nac = DateTime.Parse(fecha_nac);
                    }
                    catch
                    {
                        elemento.fecha_nac = FechaNula;
                    }
                    elemento.precio_especial = double.Parse(precio_especial);
                    elemento.empresa = false;
                    try
                    {
                        elemento.empresa = int.Parse(es_empresa) == 1 ? true : false;
                    }
                    catch { }
                    elemento.dni_cif = dni_cif;
                    elemento.vip = false;
                    try
                    {
                        elemento.vip = int.Parse(vip) == 1 ? true : false;
                    }
                    catch { }
                    elemento.E_mail = E_mail;
                    elemento.localidad = localidad;
                    elemento.ciudad = ciudad;
                    elemento.zip_code = zip_code;
                    elemento.provincia = provincia;
                    elemento.observaciones = observaciones;
                    elemento.id_naci = int.Parse(id_naci);
                    elemento.id_idio = int.Parse(id_idio);
                    elemento.telefonos = telefonos;
                    elemento.fax = fax;
                    elemento.referencia = referencia;
                    elemento.siglas = siglas;
                    elemento.nombre_empresa = nombre_empresa;
                    elemento.objeto_social = objeto_social;
                    elemento.nombre_gerente = nombre_gerente;
                    elemento.nombre = nombre;
                    elemento.lugar_nacimiento = lugar_nacimiento;
                    elemento.profesion = profesion;
                    elemento.tipo_doc = false;
                    try
                    {
                        elemento.tipo_doc = int.Parse(tipo_doc) == 1 ? true : false;
                    }
                    catch { }
                    elemento.sexo = false;
                    try
                    {
                        elemento.sexo = int.Parse(sexo) == 1 ? true : false;
                    }
                    catch { }
                    try
                    {
                        elemento.venc_pas = DateTime.Parse(venc_pas);
                    }
                    catch
                    {
                        elemento.venc_pas = FechaNula;
                    }
                    elemento.tarj_cred = tarj_cred;
                    elemento.venc_tarj = new DateTime(int.Parse(venc_tarj_year), int.Parse(venc_tarj_month), 1);

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    elemento.dni_cif = elemento.es_empresa ? elemento.dni_cif : numero_pas;

                    int res = -1;

                    res = Logica.PutPerfiles(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Nacionalidades e Idiomas

        [WebGet]
        [OperationContract]
        public string GetNacionalidadesIdiomas(string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    NacionalidadIdioma elemento = new NacionalidadIdioma();
                    elemento.id_naid = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetNacionalidadesIdiomas(elemento, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutNacionalidadesIdiomas(string id_naid, string id_naci, string id_lang, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    NacionalidadIdioma elemento = new NacionalidadIdioma();
                    try
                    {
                        elemento.id_naid = int.Parse(id_naid);
                    }
                    catch
                    {
                        elemento.id_naid = 0;
                    }
                    elemento.id_naci = int.Parse(id_naci);
                    elemento.id_lang = int.Parse(id_lang);

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutNacionalidadesIdiomas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Bitácora de Seguridad

        [WebGet]
        [OperationContract]
        public string GetAplicacionesCombo(string id_modulo, string I, string LangCode)
        {
            try
            {
                if (Seguridad.CargarConfiguracionManagement() == 1)
                {
                    return HTMLSelects.Aplicaciones(int.Parse(id_modulo));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.ERR("LblGENWrongQuery") + ":</b></br> " + Memoria.Error + "\n" + ex.Message + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetDatosComboBS(string id_modulo, string I, string LangCode)
        {
            try
            {
                if (Seguridad.CargarConfiguracionManagement() == 1)
                {
                    return HTMLSelects.DatosLog(int.Parse(id_modulo));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.ERR("LblGENWrongQuery") + ":</b></br> " + Memoria.Error + "\n" + ex.Message + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetOpcionesCombo(string id_app, string I, string LangCode)
        {
            try
            {
                if (Seguridad.CargarConfiguracionManagement() == 1)
                {
                    return HTMLSelects.Opciones(int.Parse(id_app));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.ERR("LblGENWrongQuery") + ":</b></br> " + Memoria.Error + "\n" + ex.Message + "</p>";
            }
        }

        #endregion

        #region Impresión Directa de Documentos (IDD)

        [WebGet]
        [OperationContract]
        public string GetImpresoras(string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetImpresoras(iden))
                        .Replace("LblGENFactura", L.LBL("LblGENFactura"))
                        .Replace("LblGENRecibo", L.LBL("LblGENRecibo"))
                        .Replace("LblGENCheque", L.LBL("LblGENCheque"))
                        .Replace("LblREPPreimpresionFolio", L.REP("LblREPPreimpresionFolio"))
                        .Replace("LblFDKPCIERFacturasEmpresas", L.LBL("LblFDKPCIERFacturasEmpresas"))
                        .Replace("LblFDKProforma", L.LBL("LblFDKProforma"))
                        .Replace("LblREPDepAdelEF", L.REP("LblREPDepAdelEF"))
                        .Replace("LblREPDepAdelTarj", L.REP("LblREPDepAdelTarj"))
                        .Replace("OFCanje", L.TIT("OFCanje"))
                        .Replace("Prepagos", L.TIT("Prepagos"))
                        .Replace("Notas", L.TIT("Notas"))
                        .Replace("Reservas", L.TIT("Reservas"))
                        .Replace("RoomingList", L.TIT("RoomingList"))
                        .Replace("TarjetaRegistro", L.TIT("TarjetaRegistro"))
                        .Replace("LblGENDocumentos", L.LBL("LblGENDocumentos"));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutImpresoras(string id_repo, string descripcion, string tipo_impresora, string id_papel, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Impresora elemento = new Impresora();
                    try
                    {
                        elemento.id_repo = int.Parse(id_repo);
                    }
                    catch
                    {
                        elemento.id_repo = 0;
                    }
                    elemento.descripcion = descripcion;
                    elemento.tipo_impresora = int.Parse(tipo_impresora);
                    elemento.id_papel = int.Parse(id_papel);

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutImpresoras(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

    }
}

